@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: text
-version: 0.11.2.3
-id: text-0.11.2.3-6d44323283fc0f3935743a72b4424942
+version: 0.11.3.1
+id: text-0.11.3.1-5af30448b2c3a30eee31b3ea9b549812
 
 license: BSD3
 copyright: 2009-2011 Bryan O'\''Sullivan, 2008-2009 Tom Harper
@@ -56,37 +56,38 @@ exposed-modules: Data.Text Data.Text.Array Data.Text.Encoding
                  Data.Text.Internal Data.Text.Lazy Data.Text.Lazy.Builder
                  Data.Text.Lazy.Builder.Int Data.Text.Lazy.Builder.RealFloat
                  Data.Text.Lazy.Encoding Data.Text.Lazy.IO Data.Text.Lazy.Internal
-                 Data.Text.Lazy.Read Data.Text.Read
+                 Data.Text.Lazy.Read Data.Text.Read Data.Text.Unsafe
 hidden-modules: Data.Text.Encoding.Fusion
                 Data.Text.Encoding.Fusion.Common Data.Text.Encoding.Utf16
                 Data.Text.Encoding.Utf32 Data.Text.Encoding.Utf8 Data.Text.Fusion
                 Data.Text.Fusion.CaseMapping Data.Text.Fusion.Common
                 Data.Text.Fusion.Internal Data.Text.Fusion.Size
                 Data.Text.IO.Internal Data.Text.Lazy.Builder.Functions
+                Data.Text.Lazy.Builder.Int.Digits Data.Text.Lazy.Builder.Internal
                 Data.Text.Lazy.Builder.RealFloat.Functions
                 Data.Text.Lazy.Encoding.Fusion Data.Text.Lazy.Fusion
                 Data.Text.Lazy.Search Data.Text.Private Data.Text.Search
-                Data.Text.Unsafe Data.Text.Unsafe.Base Data.Text.UnsafeChar
-                Data.Text.UnsafeShift Data.Text.Util
+                Data.Text.Unsafe.Base Data.Text.UnsafeChar Data.Text.UnsafeShift
+                Data.Text.Util
 trusted: False
-import-dirs: /usr/local/lib/ghc/text-0.11.2.3
-library-dirs: /usr/local/lib/ghc/text-0.11.2.3
-hs-libraries: HStext-0.11.2.3
+import-dirs: /usr/local/lib/ghc/text-0.11.3.1
+library-dirs: /usr/local/lib/ghc/text-0.11.3.1
+hs-libraries: HStext-0.11.3.1
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: array-0.4.0.0-4f6c2a594155b0b953c1cf0f54040f61
-         base-4.5.1.0-5b1c9d3d412ed227632edae6d2aca151
-         bytestring-0.9.2.1-3c5b69d9d36e3a0179d120b97025ab86
-         deepseq-1.3.0.0-c8a9e8b538aecb7581533b9c1d19faed
-         ghc-prim-0.2.0.0-23f345e1ec26a64d5ebc768bd0b2a5d9
-         integer-gmp-0.4.0.0-c15e185526893c3119f809251aac8c5b
+depends: array-0.4.0.1-3b78425c10ff2dad7acf7e8c8ae014c3
+         base-4.6.0.1-6b06c3defb20732cfd08deb8ba52ca7c
+         bytestring-0.10.0.2-1c6ab0cabcb254a0e55d751d8ef17b51
+         deepseq-1.3.0.1-5cc4cd89bdc2e8f6db1833d95ec36926
+         ghc-prim-0.3.0.0-d5221a8c8a269b66ab9a07bdc23317dd
+         integer-gmp-0.5.0.0-2f15426f5b53fe4c6490832f9b20d8d7
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-text-0.11.2.3/html/text.haddock
-haddock-html: /usr/local/share/doc/hs-text-0.11.2.3/html
-' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
+haddock-interfaces: /usr/local/share/doc/hs-text-0.11.3.1/html/text.haddock
+haddock-html: /usr/local/share/doc/hs-text-0.11.3.1/html
+' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
